﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.ComponentModel;
using System.Globalization;
using PropertyGridDemo.Properties;

namespace PropertyGridDemo.Objects
{
    public enum ValueEnum
    {
        One, Two, Three
    }
    public class ValueEnumTranslateConverter : EnumConverter
    {
        public ValueEnumTranslateConverter() 
            : base(typeof(ValueEnum))
        {

        }
        public override bool CanConvertFrom(ITypeDescriptorContext context, Type sourceType)
        {
            if (sourceType == typeof(string))
            {
                return true;
            }
            return base.CanConvertFrom(context, sourceType);
        }
        public override object ConvertFrom(ITypeDescriptorContext context, CultureInfo culture, object value)
        {
            string v = value as string;
            if (v != null)
            {
                if (string.Compare(v, Resources.VE_ONE, true) == 0)
                {
                    return ValueEnum.One;
                }
                else if (string.Compare(v, Resources.VE_TWO, true) == 0)
                {
                    return ValueEnum.Two;
                }
                else if (string.Compare(v, Resources.VE_THREE, true) == 0)
                {
                    return ValueEnum.Three;
                }
                else
                {
                    return context.PropertyDescriptor.GetValue(context.Instance);
                }
            }
            return base.ConvertFrom(context, culture, value);
        }
        public override object ConvertTo(ITypeDescriptorContext context, CultureInfo culture, object value, Type destinationType)
        {
            if (destinationType == typeof(string))
            {
                switch ((ValueEnum)value)
                {
                    case ValueEnum.One:
                        return Resources.VE_ONE;
                    case ValueEnum.Two:
                        return Resources.VE_TWO;
                    default:
                        return Resources.VE_THREE;
                }
            } 
            return base.ConvertTo(context, culture, value, destinationType);
        }
    }
}
